import prefect
from datamonk.utils import functions as utils, monitoring

import datamonk.scriptorium.apps.dataform as dataform
import os

@prefect.task
def dataform_transform(project_id=os.environ.get("DATAFORM_PROJECT_ID"),
                       token=os.environ.get("DATAFORM_API_KEY"),
                       schedule=os.environ.get("DATAFORM_SCHEDULE_NAME")
                       ):
       df_inst=dataform.instance(project_id=project_id,
                                 token=token)
       return df_inst.run(schedule=schedule)


@prefect.task
def data_monitoring(config_json_path):
    config=functions.local.read_configJSON(path=config_json_path)
    return monitoring.run(rules_list=config["rules"])

def prefect_parameter_read_json(path,param_name):
        return prefect.Parameter(param_name,
                                 default=utils.functions.local(path,"string")
                                 )


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['prefect_tasks']

package_data = \
{'': ['*']}

install_requires = \
['datamonk-invest-tools>=0.1.1,<0.2.0',
 'datamonk-scriptorium>=0.5.0,<0.6.0',
 'datamonk-utils>=0.1.0,<0.2.0',
 'prefect>=1.2.4,<2.0.0']

setup_kwargs = {
    'name': 'datamonk-prefect-tasks',
    'version': '0.1.1',
    'description': '',
    'long_description': None,
    'author': 'Vit Mrnavek',
    'author_email': 'vit.mrnavek@datamonk.cz',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8.0,<3.10.0',
}


setup(**setup_kwargs)
